Crate linux_socketcan_iso_tp

Crate linux_socketcan_iso_tp 

Linux kernel ISO-TP socket backend.

On Linux this provides a minimal wrapper around CAN_ISOTP sockets and implements the can-isotp-interface traits.

On non-Linux targets this crate provides compile-time stubs so downstream crates can build with appropriate cfg gating.

Modules

flags
Kernel ISO-TP flag constants.

Structs

IsoTpFlowControlOptions
Flow control options advertised by the kernel.
IsoTpKernelOptions
Kernel ISO-TP socket configuration.
IsoTpLinkLayerOptions
Link-layer options for kernel ISO-TP sockets.
IsoTpSocketOptions
Socket-level ISO-TP options.
KernelUdsDemux
Kernel-backed ISO-TP demux for UDS normal-fixed addressing (0x18DA_TA_SA).
SocketCanIsoTp
Kernel ISO-TP endpoint using a single socket.

Enums

Error
ISO-TP socket error type.